@@ -7,6 +7,8 @@ BRANCH_ALREADY_EXISTS_RE = r"fatal: A branch named '\w+' already exists."
 BRANCH_NOT_FOUND_RE = r"error: branch '\w+' not found."
 BRANCH_REFNAME_NOT_FOUND_RE = r"error: refname \w+ not found"
 NOT_VALID_OBJECT_NAME_RE = r"fatal: Not a valid object name \w+"
+INVALID_OBJECT_NAME = r"fatal: invalid object name '.+'"
+PATH_DOES_NOT_EXIST = r"fatal: path '.+' does not exist in '.+'"
 # git ls-tree <tree-ish>
 LS_TREE_RE = r"^(\d{6}) (\w+) (\w{40})\t(.+)$"
 # git ls-tree <tree-ish> -l
